@@ -1,4 +1,4 @@
-# Copyright 2004-2017 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2018 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -285,10 +285,24 @@ class ScreenDisplayable(renpy.display.layout.Container):
     class is responsible for managing the display of a screen.
     """
 
-    nosave = [ 'screen', 'child', 'children', 'transforms', 'widgets', 'old_widgets', 'hidden_widgets', 'old_transforms', 'cache', 'profile', 'phase', 'use_cache' ]
+    nosave = [
+        'screen',
+        'child',
+        'children',
+        'transforms',
+        'widgets',
+        'old_widgets',
+        'hidden_widgets',
+        'old_transforms',
+        'cache',
+        'miss_cache',
+        'profile',
+        'phase',
+        'use_cache' ]
 
     restarting = False
     hiding = False
+    transient = False
 
     def after_setstate(self):
         self.screen = get_screen_variant(self.screen_name[0])
@@ -302,10 +316,11 @@ class ScreenDisplayable(renpy.display.layout.Container):
         self.cache = { }
         self.phase = UPDATE
         self.use_cache = { }
+        self.miss_cache = { }
 
         self.profile = profile.get(self.screen_name, None)
 
-    def __init__(self, screen, tag, layer, widget_properties={}, scope={}, **properties):
+    def __init__(self, screen, tag, layer, widget_properties={}, scope={}, transient=False, **properties):
 
         super(ScreenDisplayable, self).__init__(**properties)
 
@@ -362,6 +377,11 @@ class ScreenDisplayable(renpy.display.layout.Container):
         else:
             self.use_cache = { }
 
+        # A version of the cache that's used when we have a screen that is
+        # being displayed with the same tag with a cached copy of the screen
+        # we want to display.
+        self.miss_cache = { }
+
         # What widgets and transforms were the last time this screen was
         # updated. Used to communicate with the ui module, and only
         # valid during an update - not used at other times.
@@ -384,6 +404,9 @@ class ScreenDisplayable(renpy.display.layout.Container):
         self.restarting = False
         self.hiding = False
 
+        # Is this a transient screen?
+        self.transient = transient
+
         # Modal and zorder.
         self.modal = renpy.python.py_eval(self.screen.modal, locals=self.scope)
         self.zorder = renpy.python.py_eval(self.screen.zorder, locals=self.scope)
@@ -435,12 +458,25 @@ class ScreenDisplayable(renpy.display.layout.Container):
 
         return rv
 
+    def _handles_event(self, event):
+        if self.child is None:
+
+            if self.transient:
+                return False
+
+            self.update()
+
+        return self.child._handles_event(event)
+
     def _hide(self, st, at, kind):
 
         if self.phase == HIDE:
             hid = self
         else:
 
+            if (self.child is not None) and (not self.child._handles_event(kind)):
+                return None
+
             updated_screens.discard(self)
             self.update()
 
@@ -450,6 +486,9 @@ class ScreenDisplayable(renpy.display.layout.Container):
             if self.child is None:
                 return None
 
+            if not self.child._handles_event(kind):
+                return None
+
             if self.screen.ast is not None:
                 self.screen.ast.copy_on_change(self.cache.get(0, {}))
 
@@ -468,7 +507,7 @@ class ScreenDisplayable(renpy.display.layout.Container):
             return None
 
         renpy.ui.detached()
-        hid.child = renpy.ui.fixed(focus="_screen_" + "_".join(self.screen_name))
+        hid.child = renpy.ui.default_fixed(focus="_screen_" + "_".join(self.screen_name))
         hid.children = [ hid.child ]
         renpy.ui.close()
 
@@ -570,7 +609,7 @@ class ScreenDisplayable(renpy.display.layout.Container):
         try:
 
             renpy.ui.detached()
-            self.child = renpy.ui.fixed(focus="_screen_" + "_".join(self.screen_name))
+            self.child = renpy.ui.default_fixed(focus="_screen_" + "_".join(self.screen_name))
             self.children = [ self.child ]
 
             self.scope["_scope"] = self.scope
@@ -582,6 +621,8 @@ class ScreenDisplayable(renpy.display.layout.Container):
             renpy.ui.close()
 
         finally:
+            del self.scope["_scope"]
+
             renpy.ui.screen = old_ui_screen
             pop_current_screen()
 
@@ -590,6 +631,9 @@ class ScreenDisplayable(renpy.display.layout.Container):
         self.old_transforms = None
         self.old_transfers = True
 
+        if self.miss_cache:
+            self.miss_cache.clear()
+
         # Deal with the case where the screen version changes.
         if (self.cache.get(NAME, None) is not old_cache) and (self.current_transform_event is None) and (self.phase == UPDATE):
             self.current_transform_event = "update"
@@ -954,7 +998,9 @@ def get_screen(name, layer=None):
         if sd is not None:
             return sd
 
-        sd = sl.get_displayable_by_name(layer, name)
+    for tag in name:
+
+        sd = sl.get_displayable_by_name(layer, (tag, ))
         if sd is not None:
             return sd
 
@@ -1035,12 +1081,13 @@ def show_screen(_screen_name, *_args, **kwargs):
     else:
         scope.update(kwargs)
 
-    d = ScreenDisplayable(screen, _tag, _layer, _widget_properties, scope)
+    d = ScreenDisplayable(screen, _tag, _layer, _widget_properties, scope, transient=_transient)
 
-    old_d = get_screen(name, _layer)
+    old_d = get_screen(_tag, _layer)
 
     if old_d and old_d.cache:
         d.cache = old_d.cache
+        d.miss_cache = cache_get(screen, _args, kwargs)
         d.phase = UPDATE
     else:
         d.cache = cache_get(screen, _args, kwargs)
@@ -1118,6 +1165,9 @@ def predict_screen(_screen_name, *_args, **kwargs):
             print("While predicting screen", _screen_name)
             traceback.print_exc()
 
+    finally:
+        del scope["_scope"]
+
     renpy.ui.reset()
 
 
@@ -1168,7 +1218,10 @@ def use_screen(_screen_name, *_args, **kwargs):
     scope["_scope"] = scope
     scope["_name"] = (_name, name)
 
-    screen.function(**scope)
+    try:
+        screen.function(**scope)
+    finally:
+        del scope["_scope"]
 
     _current_screen.old_transfers = old_transfers
 
@@ -1280,3 +1333,20 @@ def show_overlay_screens(suppress_overlay):
         for i in renpy.config.overlay_screens:
             if get_screen(i) is not None:
                 hide_screen(i)
+
+
+def per_frame():
+    """
+    Called from interact once per frame to invalidate screens we want to
+    update once per frame.
+    """
+
+    for i in renpy.config.per_frame_screens:
+        s = get_screen(i)
+
+        if s is None:
+            continue
+
+        updated_screens.discard(s)
+        renpy.display.render.invalidate(s)
+        s.update()
